# Acknowledgements

If you make use of this package in a publication, please cite the following:

```raw
[Pending Zenodo link - for now, just reference the GitHub repo]
```

## Funding

This project is funded by ESA through [Swarm DISC (Data, Innovation, and Science Cluster)](https://earth.esa.int/eogateway/activities/swarm-disc) as well as through other [Swarm mission](https://earth.esa.int/eogateway/missions/swarm) funding. In particular, the following Swarm projects have contributed to this work:
- Time-Frequency Analysis (TFA) toolbox
- [Dipolar Spherical Elementary Current Systems (DSECS) toolbox](https://earth.esa.int/eogateway/activities/dsecs)

## Dependencies

The following packages are used within SwarmPAL and we encourage acknowledging these as well:

- ... from the [Python in Heliophysics Community (PyHC)](https://heliopython.org):
    - [apexpy](https://github.com/aburrell/apexpy)
    - [cdflib](https://github.com/MAVENSDC/cdflib)
    - [hapiclient](https://github.com/hapi-server/client-python)
    - [viresclient](https://github.com/ESA-VirES/VirES-Python-Client)
- ... and wider Python ecosystem, including, but not limited to:
    - [NumPy](https://numpy.org/citing-numpy)
    - [Matplotlib](https://matplotlib.org/stable/users/project/citing.html)
    - [SciPy](https://scipy.org/citing-scipy)
    - [xarray](https://docs.xarray.dev/en/stable/getting-started-guide/faq.html#how-should-i-cite-xarray)
